export enum ConnectionMethod {
    internet_exchange = "internet_exchange",
    open_exchange = "open_exchange",
    direct = "direct",
    geant = "geant",
    other = "other",
}

export enum ConnectivityPage {
    ConnectedProportion = "proportion",
    ConnectivityLevel = "level",
    ConnectionCarrier = "carrier",
    ConnectivityLoad = "load",
    ConnectivityGrowth = "growth",
    CommercialConnectivity = "commercial",
    CommercialChargingLevel = "charging",
}

export enum ServiceCategory {
    network_services = "network_services",
    isp_support = "isp_support",
    security = "security",
    identity = "identity",
    collaboration = "collaboration",
    multimedia = "multimedia",
    storage_and_hosting = "storage_and_hosting",
    professional_services = "professional_services",
}

export interface AlienWave extends NrenAndYearDatapoint {
    alien_wave_third_party: string | null;
    nr_of_alien_wave_third_party_services: string | null;
}

export interface AlienWaveInternal extends NrenAndYearDatapoint {
    alien_wave_internal: string | null;
}

interface BasicDatasetEntry {
    backgroundColor: string | string[];
    borderColor?: string;
    data: (number | null)[];
    label: string;
    hidden: boolean;
}

export interface BasicDataset {
    labels: string[];
    datasets: BasicDatasetEntry[];
}

interface BarChartEntry extends BasicDatasetEntry {
    borderSkipped: boolean,
    barPercentage: number,
    borderWidth: number,
    categoryPercentage: number,
    stack: string
    borderRadius?: number
}

export interface BarChartDataset {
    labels: string[];
    datasets: BarChartEntry[];
}

export interface Budget extends NrenAndYearDatapoint {
    budget: number;
}

export interface Capacity extends NrenAndYearDatapoint {
    largest_link_capacity: string | null;
    typical_backbone_capacity: string | null;
}

export interface CentralProcurement extends NrenAndYearDatapoint {
    central_procurement: boolean;
    amount: number | null;
}

export interface CertificateProviders extends NrenAndYearDatapoint {
    provider_names: string[];
}

export interface ChargingStructure extends NrenAndYearDatapoint {
    fee_type: string | null;
}

export interface ConnectedInstitutionURLs extends URLDatapoint {
    urls: string[];
}

export interface ConnectedProportion extends NrenAndYearDatapoint {
    // strategic_plan: string,
    user_category: string;
    coverage: string;
    number_connected: number;
    market_share: number;
    users_served: number;
}

export interface ConnectionCarrier extends NrenAndYearDatapoint {
    user_category: string;
    carry_mechanism: string;
}

export interface ConnectivityGrowth extends NrenAndYearDatapoint {
    user_category: string;
    growth: number;
}

export interface ConnectivityLevel extends NrenAndYearDatapoint {
    user_category: string;
    typical_speed: number;
    highest_speed: number;
    highest_speed_proportion: number;
}

export interface ConnectivityLoad extends NrenAndYearDatapoint {
    user_category: string;
    average_load_from_institutions: number;
    average_load_to_institutions: number;
    peak_load_from_institutions: number;
    peak_load_to_institutions: number;
}

export interface CorporateStrategy extends NrenAndYearDatapoint {
    strategic_plan: string;
}

export interface CrisisExercises extends NrenAndYearDatapoint {
    exercise_descriptions: string[];
}

export interface DarkFibreInstalled extends NrenAndYearDatapoint {
    installed: boolean;
    fibre_length_in_country: number | null;
}

export interface DarkFibreLease extends NrenAndYearDatapoint {
    iru_or_lease: boolean;
    fibre_length_in_country: number | null;
    fibre_length_outside_country: number | null;
    iru_duration: number | null;
}

export interface ECProject extends NrenAndYearDatapoint {
    project: string;
}

export interface EOSCListing extends NrenAndYearDatapoint {
    service_names: string[];
}

export interface ExternalConnection extends NrenAndYearDatapoint {
    link_name: string,
    capacity: (number | null),
    from_organization: string,
    to_organization: string,
    interconnection_method: (ConnectionMethod | string | null),
}

export interface FilterSelection {
    selectedNrens: string[];
    selectedYears: number[];
}

export interface FibreLight extends NrenAndYearDatapoint {
    light_description: string;
}

export interface FundingSource extends NrenAndYearDatapoint {
    client_institutions: number;
    commercial: number;
    european_funding: number;
    gov_public_bodies: number;
    other: number;
}

export interface MonitoringTools extends NrenAndYearDatapoint {
    tool_descriptions: string[];
    netflow_processing_description: string;
}

export interface NetworkAutomation extends NrenAndYearDatapoint {
    network_automation: string;
    network_automation_specifics: string[];
}

export interface NetworkFunctionVirtualisation extends NrenAndYearDatapoint {
    nfv: string;
    nfv_specifics: string[];
}

export interface NetworkMapUrls extends URLDatapoint {
    weather_map: boolean;
    urls: string[];
}

export interface NonRAndEPeers extends NrenAndYearDatapoint {
    nr_of_non_r_and_e_peers: number;
}

export interface Nren {
    name: string;
    country: string;
}

export interface NrenAndYearDatapoint {
    nren: string;
    nren_country: string;
    year: number;
}

export interface NrenStaff extends NrenAndYearDatapoint {
    permanent_fte: number;
    subcontracted_fte: number;
    technical_fte: number;
    non_technical_fte: number;
}

export interface OPsAutomation extends NrenAndYearDatapoint {
    ops_automation: string;
    ops_automation_specifics: string;
}

export interface Organisation extends NrenAndYearDatapoint {
    name: string;
    role?: string;
}

export interface PassiveMonitoring extends NrenAndYearDatapoint {
    monitoring: boolean;
    method: string | null;
}

export interface PertTeam extends NrenAndYearDatapoint {
    pert_team: string;
}

export interface Policy extends NrenAndYearDatapoint {
    acceptable_use: string;
    connectivity: string;
    data_protection: string;
    environmental: string;
    equal_opportunity: string;
    privacy_notice: string;
    strategic_plan: string;
}

interface RemoteCampus {
    country: string;
    local_r_and_e_connection: (boolean | null);
}

export interface RemoteCampuses extends NrenAndYearDatapoint {
    remote_campus_connectivity: boolean;
    connections: RemoteCampus[];
}

export interface SecurityControls extends NrenAndYearDatapoint {
    security_control_descriptions: string[];
}

export interface Service extends NrenAndYearDatapoint {
    service_category: ServiceCategory;
    service_name: string;
    service_description: string;
    product_name: string;
    official_description: string;
    additional_information: string;
}

export interface ServiceManagement extends NrenAndYearDatapoint {
    service_management_framework: string | null;
    service_level_targets: string | null;
}

export interface ServiceOffered extends NrenAndYearDatapoint {
    user_category: string;
    service_category: string;
}

export interface SiemVendors extends NrenAndYearDatapoint {
    vendor_names: string[];
}

export interface Standards extends NrenAndYearDatapoint {
    audits: string | null;
    audit_specifics: string;
    business_continuity_plans: string | null;
    business_continuity_plans_specifics: string;
    crisis_management_procedure: string | null;
}

export interface TrafficRatio extends NrenAndYearDatapoint {
    r_and_e_percentage: number;
    commodity_percentage: number;
}

export interface TrafficStatistics extends URLDatapoint {
    traffic_statistics: boolean;
    urls: string[];
}

export interface TrafficVolume extends NrenAndYearDatapoint {
    from_customers: number;
    to_customers: number;
    from_external: number;
    to_external: number;
}

export interface URLDatapoint extends NrenAndYearDatapoint {
    urls?: string[];
    url?: string;
}

export interface User {
    id: string;
    email: string;
    role: string;
    name: string;
    oidc_sub: string;
    nrens: string[];
    permissions: {
        admin: boolean;
        active: boolean;
    };
}

export interface WeatherMap extends URLDatapoint {
    weather_map: boolean;
    url: string;
}
