import React, { ReactElement, useRef, useEffect } from "react";
import { Link } from 'react-router-dom';
import { Row } from 'react-bootstrap';

interface inputProps {
    to: string,
    children: React.ReactNode
}

function LinkWithHighlight({ to, children }: inputProps): ReactElement {
    const currentPageIsTo = window.location.pathname === to;
    const ref = useRef<HTMLAnchorElement>(null);

    useEffect(() => {
        if (currentPageIsTo && ref.current) {
            // scroll the link into view in the sidebar
            ref.current.scrollIntoView({ behavior: "smooth", block: "center" });
        }
    }, [currentPageIsTo]);

    return (
        <Row>
            <Link to={to} className="link-text-underline" ref={ref}>
                {currentPageIsTo ? <b>{children}</b> : children}
            </Link>
        </Row>
    );
}

export default LinkWithHighlight;