import React, { ReactElement } from "react";
import { Container, Row } from "react-bootstrap";
import CollapsibleBox from "compendium/components/CollapsibleBox";
import PageHeader from "compendium/components/global/PageHeader"
import Banner from "compendium/components/global/Banner";
import { Sections } from "compendium/helpers/constants";
import { usePreview } from "compendium/helpers/usePreview";
import useMatomo from "compendium/matomo/UseMatomo";
import OrganizationLinks from "compendium/components/sections/OrganizationLinks";
import PolicyLinks from "compendium/components/sections/PolicyLinks";
import ConnectedUsersLinks from "compendium/components/sections/ConnectedUsersLinks";
import NetworkLinks from "compendium/components/sections/NetworkLinks";
import ServicesLinks from "compendium/components/sections/ServicesLinks";

function CompendiumData(): ReactElement {
    usePreview();

    const { trackPageView } = useMatomo()

    React.useEffect(() => {
        trackPageView({
            documentTitle: 'Compendium Data'
        })
    }, [trackPageView])

    return (
        <>
            <PageHeader type={'data'} />
            <Banner type={'data'}>
                <p className="wordwrap">
                    The GÉANT Compendium provides an authoritative reference source for anyone with an
                    interest in the development of research and education networking in Europe and beyond.
                    Published since 2001, the Compendium provides information on key areas such as users,
                    services, traffic, budget and staffing.
                </p>
            </Banner>

            <Container className="mt-5 mb-5">
                <Row>
                    <CollapsibleBox title={Sections.Organisation}>
                        <OrganizationLinks />
                    </CollapsibleBox>

                    <CollapsibleBox title={Sections.Policy} startCollapsed>
                        <PolicyLinks />
                    </CollapsibleBox>

                    <CollapsibleBox title={Sections.ConnectedUsers} startCollapsed>
                        <ConnectedUsersLinks />
                    </CollapsibleBox>
                    <CollapsibleBox title={Sections.Network} startCollapsed>
                        <NetworkLinks />
                    </CollapsibleBox>
                    <CollapsibleBox title={Sections.Services} startCollapsed>
                        <ServicesLinks />
                    </CollapsibleBox>
                </Row>
            </Container>
        </>
    );
}

export default CompendiumData;
