import { useContext } from 'react';

import { URLDatapoint } from "compendium/Schema";
import { createDataLookup, getLatestData, extractUrls, getTableData } from 'compendium/helpers/dataconversion';
import DataPage from 'compendium/components/DataPage';
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from 'compendium/providers/FilterSelectionProvider';
import { useData } from "compendium/helpers/useData";
import ChartContainer from 'compendium/components/graphing/ChartContainer';
import NrenYearTable from 'compendium/components/NrenYearTable';
import titles from "compendium/titles";

function ConnectedInstitutionsURLsPage() {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, nrens } = useData<URLDatapoint>('/api/institution-urls', setFilterSelection);

    const institutionData = data ? getLatestData(data) : [];

    const selectedData = institutionData.filter(institution =>
        filterSelection.selectedNrens.includes(institution.nren)
    );

    const institutionDataByYear = createDataLookup(selectedData);

    const addValueToObject = (obj: { [key: string]: string }, data: URLDatapoint) => {
        const value = extractUrls(data);
        if (value == null) return;
        for (const [key, text] of Object.entries(value)) {
            obj[key] = text;
        }
    }

    const dataByYear = getTableData(institutionDataByYear, addValueToObject);

    const filterNode = <Filter
        filterOptions={{ availableYears: [], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />;

    const downloadData = selectedData.map(institution => ({
        ...institution,
        urls: (institution.urls ?? []).join(', ')
    }));

    return (
        <DataPage title={titles["institutions-urls"]}
            description='Many NRENs have a page on their website listing user institutions. Links to the pages are shown in the table below.'
            category={Sections.ConnectedUsers} filter={filterNode}
            data={downloadData} filename="institution_urls">
            <ChartContainer>
                <NrenYearTable data={dataByYear} columnTitle="Institution URLs" keysAreURLs noDots />
            </ChartContainer>
        </DataPage>
    );
}

export default ConnectedInstitutionsURLsPage;
