import React, { useContext } from "react";
import { PassiveMonitoring } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function PassiveMonitoringPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<PassiveMonitoring>('/api/passive-monitoring', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, 'method', true);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    const columns = [
        "No monitoring occurs",
        "SPAN ports",
        "Passive optical TAPS",
        "Both SPAN ports and passive optical TAPS",
    ]

    const columnValueMap = new Map<string, string>([
        [columns[0], "null"],
        [columns[1], "span_ports"],
        [columns[2], "taps"],
        [columns[3], "both"],
    ]);

    return (
        <DataPage title={titles['passive-monitoring']}
            description="The table below shows the methods NRENs use for the passive monitoring of international traffic."
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="passive_monitoring_nrens_per_year">
            <ChartContainer>
                <PillTable columns={columns} dataLookup={dataLookup} columnLookup={columnValueMap} />
            </ChartContainer>
        </DataPage>
    );
}
export default PassiveMonitoringPage;
