import React, { useContext } from "react";
import { CrisisExercises } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function CrisisExercisesPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<CrisisExercises>('/api/crisis-exercises', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, 'exercise_descriptions');

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    const stringMap = {
        "geant_workshops": "We participate in GEANT Crisis workshops such as CLAW",
        "national_excercises": "We participated in National crisis exercises ",
        "tabletop_exercises": "We run our own tabletop exercises",
        "simulation_excercises": "We run our own simulation exercises",
        "other_excercises": "We have done/participated in other exercises or trainings",
        "real_crisis": "We had a real crisis",
        "internal_security_programme": "We run an internal security awareness programme",
        "none": "No, we have not done any crisis exercises or trainings",
    }

    const columnValueMap = new Map<string, string>(
        Object.entries(stringMap).map(([key, value]) => [value, key])
    );

    return (
        <DataPage title={titles["crisis-exercise"]}
            description="Many NRENs run or participate in crisis exercises to test procedures and train employees. 
            The table below shows whether NRENs have run or participated in an exercise in the previous year. "
            category={Sections.Policy} filter={filterNode}
            data={selectedData} filename="crisis_exercise_nrens_per_year">
            <ChartContainer>
                <PillTable columns={Object.values(stringMap)} dataLookup={dataLookup} circle columnLookup={columnValueMap} />
            </ChartContainer>
        </DataPage>
    );
}
export default CrisisExercisesPage;
