import { useState, useEffect } from "react";

interface User {
    id?: string,
    name: string,
    email?: string
}

async function fetchUser(): Promise<User> {
    try {
        const response = await fetch('/api/user/');
        const user = await response.json();
        return user
    } catch {
        return {
            'name': 'Error Fetching User'
        }
    }
}

function ShowUser() {
    const [user, setUser] = useState<User | null>(null);

    useEffect(() => {
        // Fetch user
        fetchUser().then((user) => {
            setUser(user);
        });
    }, []);

    if (!user || user.name.match(/Anonymous/gi)) {
        return (
            <>
                <h2>Not logged in.</h2>
                <a href="/login">Login</a>
            </>

        );
    }

    return <h2>Hello, {user.name}!</h2>;

}

export default ShowUser;